@@ -1,7 +1,7 @@
 import requests
 import json
 
-class UwsgiItClient:
+class UwsgiItClient(object):
     def __init__(self, username, password, url):
         self.username = username
         self.password = password
@@ -74,7 +74,7 @@ class UwsgiItClient:
 
     def containers(self, tags=None):
         if tags:
-            params = { "tags": ",".join(tags)}
+            params = {"tags": ",".join(tags)}
         else:
             params = None
         return self.get("containers", params)
@@ -87,19 +87,22 @@ class UwsgiItClient:
 
     def domains(self, tags=None):
         if tags:
-            params = { "tags": ",".join(tags)}
+            params = {"tags": ",".join(tags)}
         else:
             params = None
         return self.get("domains", params)
 
+    def domain(self, id):
+        return self.get(["domains", id])
+
     def update_me(self, data):
         return self.post("me", data)
 
     def add_domain(self, domain):
-        return self.post("domains", {'name': domain })
+        return self.post("domains", {'name': domain})
 
     def delete_domain(self, domain):
-        return self.delete("domains", {'name': domain })
+        return self.delete("domains", {'name': domain})
 
     def update_domain(self, domain, data):
         return self.post(["domains", domain], data)
@@ -108,10 +111,10 @@ class UwsgiItClient:
         return self.post(["containers", container], data)
 
     def container_set_distro(self, container, distro):
-        return self.update_container(container, {'distro': distro })
+        return self.update_container(container, {'distro': distro})
 
     def container_set_keys(self, container, keys):
-        return self.update_container(container, {'ssh_keys': keys })
+        return self.update_container(container, {'ssh_keys': keys})
 
     def reboot_container(self, container):
         return self.post(["containers", container], {'reboot': 1})
@@ -124,3 +127,9 @@ class UwsgiItClient:
 
     def list_tags(self):
         return self.get("tags")
+
+    def container_metric(self, container, metric, params=None):
+        return self.get(['metrics', 'container.{}'.format(metric), container], params)
+
+    def domain_metric(self, domain, metric, params=None):
+        return self.get(['metrics', 'domain.{}'.format(metric), domain], params)
